Class: EventQ::Queue
- Inherits:
-
Object
- Object
- EventQ::Queue
- Defined in:
- lib/eventq/eventq_base/queue.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#allow_exponential_back_off ⇒ Object
Returns the value of attribute allow_exponential_back_off.
-
#allow_retry ⇒ Object
Returns the value of attribute allow_retry.
-
#allow_retry_back_off ⇒ Object
Returns the value of attribute allow_retry_back_off.
-
#dlq ⇒ Object
Returns the value of attribute dlq.
-
#isolated ⇒ Object
Flag to control that the queue runs in isolation of auto creating the topic it belongs to.
-
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
-
#max_retry_attempts ⇒ Object
Returns the value of attribute max_retry_attempts.
-
#max_retry_delay ⇒ Object
Returns the value of attribute max_retry_delay.
-
#name ⇒ Object
Returns the value of attribute name.
-
#namespace_delimiter ⇒ Object
Character delimiter between namespace and queue name.
-
#require_signature ⇒ Object
Returns the value of attribute require_signature.
-
#retry_back_off_grace ⇒ Object
Returns the value of attribute retry_back_off_grace.
-
#retry_back_off_weight ⇒ Object
Returns the value of attribute retry_back_off_weight.
-
#retry_delay ⇒ Object
Returns the value of attribute retry_delay.
-
#retry_jitter_ratio ⇒ Object
Returns the value of attribute retry_jitter_ratio.
Instance Method Summary collapse
-
#initialize ⇒ Queue
constructor
A new instance of Queue.
- #log_settings ⇒ Object
Constructor Details
#initialize ⇒ Queue
Returns a new instance of Queue.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/eventq/eventq_base/queue.rb', line 21 def initialize @allow_retry = false # Default retry back off settings @allow_retry_back_off = false # Default exponential back off settings @allow_exponential_back_off = false # Default max receive count is 30 @max_receive_count = 30 # Default max retry attempts is 5 @max_retry_attempts = 5 # Default max retry_delay is 5000 (5seconds) @max_retry_delay = 5000 # Default require signature to false @require_signature = false # Default retry delay is 30 seconds @retry_delay = 30000 # This is the amount of times to allow retry to occurr before back off is implemented @retry_back_off_grace = 0 # Multiplier for the backoff retry in case retry_delay is too small @retry_back_off_weight = 1 # Ratio of how much jitter to apply to the retry delay @retry_jitter_ratio = 0 @isolated = false end |
Instance Attribute Details
#allow_exponential_back_off ⇒ Object
Returns the value of attribute allow_exponential_back_off.
5 6 7 |
# File 'lib/eventq/eventq_base/queue.rb', line 5 def allow_exponential_back_off @allow_exponential_back_off end |
#allow_retry ⇒ Object
Returns the value of attribute allow_retry.
3 4 5 |
# File 'lib/eventq/eventq_base/queue.rb', line 3 def allow_retry @allow_retry end |
#allow_retry_back_off ⇒ Object
Returns the value of attribute allow_retry_back_off.
4 5 6 |
# File 'lib/eventq/eventq_base/queue.rb', line 4 def allow_retry_back_off @allow_retry_back_off end |
#dlq ⇒ Object
Returns the value of attribute dlq.
6 7 8 |
# File 'lib/eventq/eventq_base/queue.rb', line 6 def dlq @dlq end |
#isolated ⇒ Object
Flag to control that the queue runs in isolation of auto creating the topic it belongs to
19 20 21 |
# File 'lib/eventq/eventq_base/queue.rb', line 19 def isolated @isolated end |
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
10 11 12 |
# File 'lib/eventq/eventq_base/queue.rb', line 10 def max_receive_count @max_receive_count end |
#max_retry_attempts ⇒ Object
Returns the value of attribute max_retry_attempts.
7 8 9 |
# File 'lib/eventq/eventq_base/queue.rb', line 7 def max_retry_attempts @max_retry_attempts end |
#max_retry_delay ⇒ Object
Returns the value of attribute max_retry_delay.
8 9 10 |
# File 'lib/eventq/eventq_base/queue.rb', line 8 def max_retry_delay @max_retry_delay end |
#name ⇒ Object
Returns the value of attribute name.
9 10 11 |
# File 'lib/eventq/eventq_base/queue.rb', line 9 def name @name end |
#namespace_delimiter ⇒ Object
Character delimiter between namespace and queue name. Default = ‘-’
17 18 19 |
# File 'lib/eventq/eventq_base/queue.rb', line 17 def namespace_delimiter @namespace_delimiter end |
#require_signature ⇒ Object
Returns the value of attribute require_signature.
11 12 13 |
# File 'lib/eventq/eventq_base/queue.rb', line 11 def require_signature @require_signature end |
#retry_back_off_grace ⇒ Object
Returns the value of attribute retry_back_off_grace.
13 14 15 |
# File 'lib/eventq/eventq_base/queue.rb', line 13 def retry_back_off_grace @retry_back_off_grace end |
#retry_back_off_weight ⇒ Object
Returns the value of attribute retry_back_off_weight.
14 15 16 |
# File 'lib/eventq/eventq_base/queue.rb', line 14 def retry_back_off_weight @retry_back_off_weight end |
#retry_delay ⇒ Object
Returns the value of attribute retry_delay.
12 13 14 |
# File 'lib/eventq/eventq_base/queue.rb', line 12 def retry_delay @retry_delay end |
#retry_jitter_ratio ⇒ Object
Returns the value of attribute retry_jitter_ratio.
15 16 17 |
# File 'lib/eventq/eventq_base/queue.rb', line 15 def retry_jitter_ratio @retry_jitter_ratio end |
Instance Method Details
#log_settings ⇒ Object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/eventq/eventq_base/queue.rb', line 46 def log_settings EventQ.logger.info do <<~LOG.chomp [#{self.class}] - Settings: \ name='#{@name}', \ allow_retry='#{@allow_retry}', \ allow_retry_back_off='#{@allow_retry_back_off}', \ allow_exponential_back_off='#{@allow_exponential_back_off}', \ dlq='#{@dlq}', \ max_receive_count='#{@max_receive_count}', \ max_retry_attempts='#{@max_retry_attempts}', \ max_retry_delay='#{@max_retry_delay}', \ retry_delay='#{@retry_delay}', \ retry_back_off_grace='#{@retry_back_off_grace}', \ retry_back_off_weight='#{@retry_back_off_weight}', \ retry_jitter_ratio='#{@retry_jitter_ratio}', \ require_signature='#{@require_signature}' LOG end end |